@@ -29,14 +29,24 @@ class HeatClient(object):
         self.resource_types = self.heat.resource_types
         self.resources = self.heat.resources
 
+    def _stack_ids(self, stack_id):
+        filters = {"owner_id": stack_id,
+            "show_nested": True}
+
+        for stack in self.stacks.list(**{"filters": filters}):
+            yield stack.id
+            if stack.parent and stack.parent == stack_id:
+                for x in self._stack_ids(stack.id):
+                    yield x
+
     def create(self, fields):
         fields = fields.copy()
-        fields.update({
-            'timeout_mins': 10,
-            'disable_rollback': True})
+        fields['disable_rollback'] = True
         if 'password' in fields.get('template', {}):
             fields['password'] = fields['template']['password']
 
+        fields.setdefault('timeout_mins')
+
         try:
             return self.stacks.create(**fields)
         except heatException.HTTPException:
@@ -53,8 +63,19 @@ class HeatClient(object):
     def get(self, stack_id):
         return self.stacks.get(stack_id)
 
+    def get_stack_nested_depth(self, stack_id):
+        stack_ids = self._stack_ids(stack_id)
+        if stack_ids:
+            return len(list(stack_ids))
+
+        return 0
+
     def update(self, stack_id, **kwargs):
-        return self.stacks.update(stack_id, **kwargs)
+        try:
+            return self.stacks.update(stack_id, **kwargs)
+        except heatException.HTTPException:
+            type_, value, tb = sys.exc_info()
+            raise vnfm.HeatClientException(msg=value)
 
     def resource_attr_support(self, resource_name, property_name):
         resource = self.resource_types.get(resource_name)
